/*************************************************************************
 * Copyright 2012 Devscripts developers
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * This file may incorporate work that is in the public domain and/or
 * covered under the following copyright and permission notice:
 *
 *   Written by devscripts developers and released to the public domain,
 *   as explained at http://creativecommons.org/publicdomain/zero/1.0/
 ************************************************************************/
